==> eric4-4.4.20.tar.gz: eric4-4.4.20/eric/Helpviewer/Bookmarks/DefaultBookmarks.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module defining the default bookmarks.
"""

DefaultBookmarks = """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xbel>
<xbel version="1.0">
    <folder folded="no">
        <title>Bookmarks Bar</title>
        <bookmark href="http://eric-ide.python-projects.org/">
            <title>Eric Web Site</title>
        </bookmark>
        <bookmark href="http://www.riverbankcomputing.com/">
            <title>PyQt4 Web Site</title>
        </bookmark>
        <folder folded="no">
            <title>Qt Web Sites</title>
            <bookmark href="http://qt.nokia.com/">
                <title>Qt Web Site</title>
            </bookmark>
            <bookmark href="http://qt.nokia.com/doc/">
                <title>Qt Documentation</title>
            </bookmark>
            <bookmark href="http://qt.nokia.com/doc/qq/">
                <title>Qt Quarterly</title>
            </bookmark>
            <bookmark href="http://labs.trolltech.com/">
                <title>Qt Labs</title>
            </bookmark>
            <bookmark href="http://qtcentre.org/">
                <title>Qt Centre</title>
            </bookmark>
            <bookmark href="http://qt-apps.org/">
                <title>Qt-Apps.org</title>
            </bookmark>
        </folder>
        <folder folded="no">
            <title>Python Web Sites</title>
            <bookmark href="http://www.python.org/">
                <title>Python Language Website</title>
            </bookmark>
            <bookmark href="http://pypi.python.org/pypi">
                <title>Python Package Index: PyPI</title>
            </bookmark>
        </folder>
    </folder>
    <folder folded="yes">
        <title>Bookmarks Menu</title>
        <bookmark href="http://eric-ide.python-projects.org/">
            <title>Eric Web Site</title>
        </bookmark>
        <bookmark href="http://www.riverbankcomputing.com/">
            <title>PyQt4 Web Site</title>
        </bookmark>
        <bookmark href="javascript:location.href='mailto:?SUBJECT=' + document.title + '&amp;BODY=' + escape(location.href);">
            <title>Send Link</title>
        </bookmark>
    </folder>
</xbel>"""

==> eric_4.5.8.orig.tar.gz: eric4-4.5.8/eric/Helpviewer/Bookmarks/DefaultBookmarks.py <==
# -*- coding: utf-8 -*-

# Copyright (c) 2009 - 2012 Detlev Offenbach <detlev@die-offenbachs.de>
#

"""
Module defining the default bookmarks.
"""

DefaultBookmarks = """<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE xbel>
<xbel version="1.0">
    <folder folded="no">
        <title>Bookmarks Bar</title>
        <bookmark href="http://eric-ide.python-projects.org/">
            <title>Eric Web Site</title>
        </bookmark>
        <bookmark href="http://www.riverbankcomputing.com/">
            <title>PyQt4 Web Site</title>
        </bookmark>
        <folder folded="no">
            <title>Qt Web Sites</title>
            <bookmark href="http://qt.digia.com/">
                <title>Qt Web Site</title>
            </bookmark>
            <bookmark href="http://qt-project.org/">
                <title>Qt Project</title>
            </bookmark>
            <bookmark href="http://qt-project.org/doc/">
                <title>Qt Documentation</title>
            </bookmark>
            <bookmark href="http://blog.qt.digia.com/">
                <title>Qt Blog</title>
            </bookmark>
            <bookmark href="http://qtcentre.org/">
                <title>Qt Centre</title>
            </bookmark>
            <bookmark href="http://qt-apps.org/">
                <title>Qt-Apps.org</title>
            </bookmark>
        </folder>
        <folder folded="no">
            <title>Python Web Sites</title>
            <bookmark href="http://www.python.org/">
                <title>Python Language Website</title>
            </bookmark>
            <bookmark href="http://pypi.python.org/pypi">
                <title>Python Package Index: PyPI</title>
            </bookmark>
        </folder>
    </folder>
    <folder folded="yes">
        <title>Bookmarks Menu</title>
        <bookmark href="http://eric-ide.python-projects.org/">
            <title>Eric Web Site</title>
        </bookmark>
        <bookmark href="http://www.riverbankcomputing.com/">
            <title>PyQt4 Web Site</title>
        </bookmark>
        <bookmark href="javascript:location.href='mailto:?SUBJECT=' + document.title + '&amp;BODY=' + escape(location.href);">
            <title>Send Link</title>
        </bookmark>
    </folder>
</xbel>"""
